@@ -1,12 +1,8 @@
-extern crate colored_json;
-extern crate serde_json;
+use colored_json;
 
 use colored_json::prelude::*;
 
-fn main() -> ::std::result::Result<(), Box<::std::error::Error>> {
-    #[cfg(windows)]
-    let _enabled = colored_json::enable_ansi_support();
-
+fn main() -> Result<(), Box<dyn ::std::error::Error>> {
     println!(
         "{}",
         r#"{
@@ -16,7 +12,8 @@ fn main() -> ::std::result::Result<(), Box<::std::error::Error>> {
               ],
               "float": 3.1415926,
               "integer": 4398798674962568,
-              "string": "string"
+              "string": "string",
+              "null": null
            }
         "#
         .to_colored_json_auto()?
